#ifndef DOCUMENTED_CLASS_H
#define DOCUMENTED_CLASS_H

// This class isn't documented
struct UndocumentedClass{
  int x,y,z;
  UndocumentedClass(){};
};


/** \cond eveything until next "\endcond" command is skipped by doxygen */
/// This Class is documented but skipped
struct SkippedClass{
  SkippedClass
};
/** \endcond */

/// The DocumentedClass namespace (short description)
/** Here we can add some more detailed description 
    for the namespace 
*/
namespace doc{

  /// Short class description here
  /** Detailed class description here 
      
      This is a very nice class doing nothing!
      
      \section SEC1 Overview
      Hm.. some text here
      
      \section SEC2 Implementation
      
      Bla Bla
      
      \section Benchmark
      
      As mentioned in sec. \ref SEC2 bla bla
      
  */
  class DocumentedClass :  public UndocumentedClass{
    public:
    /// This is just a demonstration enum (short-description)
    /** And again, here's some more detailed information ... 

    */
    enum AnEnum{
      Value1,  //!< Oh what a nice value: Value1
      Value2,  //!< WOW! yet another value
      Value3   //!< and a 3rd one
    };

    /// heres a short function description
    /** Here surprise surprise: A more detailed description! 
        Oh no! line becomes to long: \n
        But we can also document each parameter separately:
        @param x the astonishing x parameter
        @param y the lame y parameter
        @return a nice value (most of the time: 5)
        
        If we want to give a link to another function, we can use the "see" macro
        @see DocumentedClass:random
    */
    int a_wonderful_function(int x, int y){
      return 5;
    }

    /// Even static members can be documented the same way
    /** @return random number obtained by two fair dice*/
    static int random(){
      return 5;
    }

    protected:
    /// Members can be documented in old-school manner
    int m_X;

    int m_Y; /// or in this way means...

    private:
    /// private members are not included to the documentation by default!
    int m_Treasure; 
  };

}


/** Sometimes we also need a main-page for our tiny project:
\mainpage FunnyMovingBall a demo example for our lectures!

 Inside of the documentation, we can use formulas 
 if latex is available on our system: \n
 Here's an in-line math-statement: \f$ f(x) = \sum_{i=1}^N i \f$ 

 Like in LaTeX we can define equations:
    \f[
    F(u) = \frac{1}{N}\sum\limits_{k=1}^N f(k)*\exp( \frac{iku2\pi}{N} ) 
    \f]

  we can also copy the documentation from elsewhere:
    
  Oh, please look at this sophisticated documentation: \n
    
  \copydoc doc::DocumentedClass::a_wonderful_function
  
    
  Maybe we want to define a list of items:
  - B
  - A
   - A.b
   - B.a ?

  Or an enumeration:
    -# ONE
    -# TWO
    -# Hello
      -# World! 
*/

#endif
