#include "animation.h"

#include <QPainter>
#include <cmath>

AnimationWidget::AnimationWidget(QWidget *parent, const QRect &geometry) :
  QWidget(parent),
  velocity(70,108) {
  setGeometry(geometry);

  pos = geometry.center();
  
  gravity = 39.82;

  lastTime = QTime::currentTime();

  connect(&timer, SIGNAL(timeout()), this, SLOT(update()));
  timer.start(50);

}

AnimationWidget::~AnimationWidget() {

}
	
void AnimationWidget::mousePressEvent(QMouseEvent * event) {
  pos = event->pos();
  velocity.rx() = 200*((float)rand()/RAND_MAX) -100;
  velocity.ry() = 0;
  posHist.clear();
}

void AnimationWidget::paintEvent(QPaintEvent * event) {
  (void)event;
  float dt = (float)QTime::currentTime().msecsTo(lastTime)/1000.0;
  lastTime = QTime::currentTime();


  
  pos+=dt * velocity;
  velocity /= pow(0.9, dt);
  velocity.ry() += dt * gravity;


  if(pos.x()<0 || pos.x() >=width()) velocity.rx() *= -1;
  if(pos.y()<0 || pos.y() >=height()) velocity.ry() *= -1;

  posHist.push_back(pos);
  if(posHist.size()>100) posHist.pop_front();

  QPainter p(this);
  
  p.setBrush(QColor(255,255,255));
  p.drawRect(0,0,width(),height());

  p.setPen(QColor(0,0,0,0));
  p.setBrush(QColor(0,100, 255));
  p.drawEllipse(pos.x()-5, pos.y()-5, 10, 10); 
  


  float idx = 0;
  for(std::list<QPointF>::iterator it = posHist.begin();
      it != posHist.end(); ++it, ++idx){

    p.setBrush(QColor(0,100, 255,255.0*(idx/100.0)));
    p.drawEllipse(it->x()-5, it->y()-5, 10, 10); 
    
      

  }
}



